pub struct OpenRequest {
pub mode: i32,
}Fields
mode: i32Implementations
Sourceimpl OpenRequest
impl OpenRequest
Sourcepub fn mode(&self) -> OpenModeProto
pub fn mode(&self) -> OpenModeProto
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: OpenModeProto)
pub fn set_mode(&mut self, value: OpenModeProto)
Sets mode to the provided enum value.