pub struct WaitForCatchUpQuorumRequest {
pub mode: i32,
}Fields
mode: i32Implementations
Sourceimpl WaitForCatchUpQuorumRequest
impl WaitForCatchUpQuorumRequest
Sourcepub fn mode(&self) -> QuorumModeProto
pub fn mode(&self) -> QuorumModeProto
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: QuorumModeProto)
pub fn set_mode(&mut self, value: QuorumModeProto)
Sets mode to the provided enum value.