pub struct ReplicatorHandle { /* private fields */ }Expand description
Handle returned by the user to the runtime at Open. The runtime uses this to drive replicator lifecycle via control events. Contains shared PartitionState for synchronous access-status fencing.
Implementations
Sourceimpl ReplicatorHandle
impl ReplicatorHandle
pub fn new( control_tx: Sender<ReplicatorControlEvent>, state: Arc<PartitionState>, data_address: String, shutdown: CancellationToken, ) -> Self
Sourcepub async fn send_control<T>(
&self,
make: impl FnOnce(Sender<Result<T>>) -> ReplicatorControlEvent,
timeout: Duration,
) -> Result<T>
pub async fn send_control<T>( &self, make: impl FnOnce(Sender<Result<T>>) -> ReplicatorControlEvent, timeout: Duration, ) -> Result<T>
Send a control event and wait for reply.
Sourcepub fn state(&self) -> &Arc<PartitionState>
pub fn state(&self) -> &Arc<PartitionState>
Synchronous access to partition state (atomics, no channel hop).
Sourcepub fn data_address(&self) -> &str
pub fn data_address(&self) -> &str
Data plane address for operator registration.