pub struct KubericRuntimeBuilder { /* private fields */ }Expand description
Builder for constructing a KubericRuntime.
Implementations
Sourceimpl KubericRuntimeBuilder
impl KubericRuntimeBuilder
pub fn new() -> Self
pub fn reply_timeout(self, timeout: Duration) -> Self
Sourcepub fn build(self) -> RuntimeBundle
pub fn build(self) -> RuntimeBundle
Build the runtime, returning it along with the channels needed to spawn the replicator actor and the user service event receivers.